aboutsummaryrefslogtreecommitdiff
path: root/engines/xeen/patcher.cpp
diff options
context:
space:
mode:
authorPaul Gilbert2019-08-22 21:05:28 -0700
committerPaul Gilbert2019-08-22 21:05:28 -0700
commit98d68b3cea4a856193fd4c30f1326a75fb73be11 (patch)
tree563eb57074832e8b7725fb20ce964983b5268869 /engines/xeen/patcher.cpp
parentb0913fcab3f5530eed375a36619c2e5e78caa9e2 (diff)
downloadscummvm-rg350-98d68b3cea4a856193fd4c30f1326a75fb73be11.tar.gz
scummvm-rg350-98d68b3cea4a856193fd4c30f1326a75fb73be11.tar.bz2
scummvm-rg350-98d68b3cea4a856193fd4c30f1326a75fb73be11.zip
XEEN: Fix pitfall destinations in Southern Tower
Diffstat (limited to 'engines/xeen/patcher.cpp')
-rw-r--r--engines/xeen/patcher.cpp8
1 files changed, 6 insertions, 2 deletions
diff --git a/engines/xeen/patcher.cpp b/engines/xeen/patcher.cpp
index 10c8664776..c8939e95f0 100644
--- a/engines/xeen/patcher.cpp
+++ b/engines/xeen/patcher.cpp
@@ -38,12 +38,16 @@ struct ScriptEntry {
const byte DS_MAP54_LINE8[] = { 8, 10, 10, DIR_EAST, 8, OP_MoveWallObj, 20, 100, 100 };
const byte SW_MAP53_LINE8[] = { 5, 14, 6, DIR_EAST, 8, OP_Exit };
const byte DS_MAP116[] = { 9, 10, 6, 4, 2, OP_TakeOrGive, 0, 0, 103, 127 };
+const byte DS_MAP62_PIT1[] = { 9, 11, 8, DIR_ALL, 4, OP_FallToMap, 61, 11, 8, 0 };
+const byte DS_MAP62_PIT2[] = { 9, 7, 4, DIR_ALL, 4, OP_FallToMap, 61, 7, 4, 0 };
-#define SCRIPT_PATCHES_COUNT 3
+#define SCRIPT_PATCHES_COUNT 6
static const ScriptEntry SCRIPT_PATCHES[] = {
{ GType_DarkSide, 54, DS_MAP54_LINE8 }, // Fix curtain on level 2 of Ellinger's Tower
{ GType_Swords, 53, SW_MAP53_LINE8 }, // Fix chest in Hart having gems, but saying "Nothing Here"
- { GType_DarkSide, 116, DS_MAP116 } // Fix statue in Dark Tower setting invalid world flag
+ { GType_DarkSide, 116, DS_MAP116 }, // Fix statue in Dark Tower setting invalid world flag
+ { GType_DarkSide, 62, DS_MAP62_PIT1 }, // Fix fall position for pit
+ { GType_DarkSide, 62, DS_MAP62_PIT2 } // Fix fall position for pit
};
/*------------------------------------------------------------------------*/